package com.bonus.material.ma.service;

import java.util.List;
import com.bonus.material.ma.domain.MachineLabel;

/**
 * 机具设备标签Service接口
 * 
 * @author xsheng
 * @date 2024-09-27
 */
public interface IMachineLabelService 
{
    /**
     * 查询机具设备标签
     * 
     * @param labelId 机具设备标签主键
     * @return 机具设备标签
     */
    public MachineLabel selectMachineLabelByLabelId(Long labelId);

    /**
     * 查询机具设备标签列表
     * 
     * @param machineLabel 机具设备标签
     * @return 机具设备标签集合
     */
    public List<MachineLabel> selectMachineLabelList(MachineLabel machineLabel);

    /**
     * 新增机具设备标签
     * 
     * @param machineLabel 机具设备标签
     * @return 结果
     */
    public int insertMachineLabel(MachineLabel machineLabel);

    /**
     * 修改机具设备标签
     * 
     * @param machineLabel 机具设备标签
     * @return 结果
     */
    public int updateMachineLabel(MachineLabel machineLabel);

    /**
     * 批量删除机具设备标签
     * 
     * @param labelIds 需要删除的机具设备标签主键集合
     * @return 结果
     */
    public int deleteMachineLabelByLabelIds(Long[] labelIds);

    /**
     * 删除机具设备标签信息
     * 
     * @param labelId 机具设备标签主键
     * @return 结果
     */
    public int deleteMachineLabelByLabelId(Long labelId);
}
