package com.bonus.material.ma.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.bonus.common.log.enums.OperaType;
import com.bonus.material.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.material.ma.domain.MachineLabel;
import com.bonus.material.ma.service.IMachineLabelService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 机具设备标签Controller
 * 
 * @author xsheng
 * @date 2024-09-27
 */
@Api(tags = "机具设备标签接口")
@RestController
@RequestMapping("/ma_machine_label")
public class MachineLabelController extends BaseController
{
    @Autowired
    private IMachineLabelService machineLabelService;

    /**
     * 查询机具设备标签列表
     */
    @ApiOperation(value = "查询机具设备标签列表")
    @RequiresPermissions("ma:label:list")
    @GetMapping("/list")
    public TableDataInfo list(MachineLabel machineLabel)
    {
        startPage();
        List<MachineLabel> list = machineLabelService.selectMachineLabelList(machineLabel);
        return getDataTable(list);
    }

    /**
     * 导出机具设备标签列表
     */
    @ApiOperation(value = "导出机具设备标签列表")
    @PreventRepeatSubmit
    @RequiresPermissions("ma:label:export")
    @SysLog(title = "机具设备标签", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出机具设备标签")
    @PostMapping("/export")
    public void export(HttpServletResponse response, MachineLabel machineLabel)
    {
        List<MachineLabel> list = machineLabelService.selectMachineLabelList(machineLabel);
        ExcelUtil<MachineLabel> util = new ExcelUtil<MachineLabel>(MachineLabel.class);
        util.exportExcel(response, list, "机具设备标签数据");
    }

    /**
     * 获取机具设备标签详细信息
     */
    @ApiOperation(value = "获取机具设备标签详细信息")
    @RequiresPermissions("ma:label:query")
    @GetMapping(value = "/{labelId}")
    public AjaxResult getInfo(@PathVariable("labelId") Long labelId)
    {
        return success(machineLabelService.selectMachineLabelByLabelId(labelId));
    }

    /**
     * 新增机具设备标签
     */
    @ApiOperation(value = "新增机具设备标签")
    @PreventRepeatSubmit
    @RequiresPermissions("ma:label:add")
    @SysLog(title = "机具设备标签", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增机具设备标签")
    @PostMapping
    public AjaxResult add(@RequestBody MachineLabel machineLabel)
    {
        return toAjax(machineLabelService.insertMachineLabel(machineLabel));
    }

    /**
     * 修改机具设备标签
     */
    @ApiOperation(value = "修改机具设备标签")
    @PreventRepeatSubmit
    @RequiresPermissions("ma:label:edit")
    @SysLog(title = "机具设备标签", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改机具设备标签")
    @PutMapping
    public AjaxResult edit(@RequestBody MachineLabel machineLabel)
    {
        return toAjax(machineLabelService.updateMachineLabel(machineLabel));
    }

    /**
     * 删除机具设备标签
     */
    @ApiOperation(value = "删除机具设备标签")
    @PreventRepeatSubmit
    @RequiresPermissions("ma:label:remove")
    @SysLog(title = "机具设备标签", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除机具设备标签")
	@DeleteMapping("/{labelIds}")
    public AjaxResult remove(@PathVariable Long[] labelIds)
    {
        return toAjax(machineLabelService.deleteMachineLabelByLabelIds(labelIds));
    }
}
